/************************************************************************************
*  Copyright (c), 2019, HelTec Automatic(TM) Technology co.,LTD.
*            All rights reserved.
*
* Http:    www.heltec.cn
* Email:   suppor@heltec.cn
* WebShop: heltec.taobao.com
*
* File name: main.c
* Processor: STM32F103VBT6
* Compiler : MDK fo ARM 5.26
* 
* Author : Aaron.Lee
* Version: 1.00
* Date   : 2019.3.7
* Email  : suppor@heltec.cn
* Modification: none
* 
* Description: Heltec 5.83" 600*448 Black-White  E-Ink driver code
*
* Others: none;
*
* Function List:
*	1. void EPD_W21_WriteCMD(uint8_t command); 			// Write Command via hardware SPI bus;
* 2. void EPD_W21_WriteDATA(uint8_t command); 		// Write data to E-Ink driver;
* 3. void WriteBuffer(unsigned  char *picture);   // Write a picture data to display buffer;
* 4. void DisplayRefresh(void); 									// Refresh display, must run this function after WriteBuffer;
* 5. void CheckStatus(void);											// Check busy;
* 6. void Display_Init(void);											// Initial display.
*
* History: none;
*
*************************************************************************************/

#include "e_ink_583_BW.h"

#include "stm32f1xx.h"

extern SPI_HandleTypeDef hspi1;


 void EPD_W21_WriteCMD(uint8_t command)
{
  HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET); 
  HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_RESET);	
	HAL_GPIO_WritePin(GPIOE, DC, GPIO_PIN_RESET);		// command write
	HAL_SPI_Transmit(&hspi1,&command,sizeof(command),100);
	HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET);
}
	
 void EPD_W21_WriteDATA(uint8_t command)
{
	HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET);
  HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_RESET);                  
	HAL_GPIO_WritePin(GPIOE, DC, GPIO_PIN_SET);			// command write
	HAL_SPI_Transmit(&hspi1,&command,sizeof(command),100);
	HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET);
}

void CheckStatus(void)
{
	while(1)
	{	 
		if(HAL_GPIO_ReadPin(GPIOE, BUSY)==1) break;
	}   
	HAL_Delay(100);                       
}

void Display_Init(void)
{		
	  HAL_Delay(100);

		EPD_W21_WriteCMD(0x01); 
		EPD_W21_WriteDATA (0x37);	    //POWER SETTING
		EPD_W21_WriteDATA (0x00);

		EPD_W21_WriteCMD(0X00);			//PANNEL SETTING
		EPD_W21_WriteDATA(0xCF);
		EPD_W21_WriteDATA(0x08);
		
		EPD_W21_WriteCMD(0x06);         //boost趨
		EPD_W21_WriteDATA (0xc7);	   	
		EPD_W21_WriteDATA (0xcc);
		EPD_W21_WriteDATA (0x28);


		EPD_W21_WriteCMD(0x30);			//PLL setting
		EPD_W21_WriteDATA (0x3c);        

		EPD_W21_WriteCMD(0X41);			//TEMPERATURE SETTING
		EPD_W21_WriteDATA(0x00);

		EPD_W21_WriteCMD(0X50);			//VCOM AND DATA INTERVAL SETTING
		EPD_W21_WriteDATA(0x77);

		EPD_W21_WriteCMD(0X60);			//TCON SETTING
		EPD_W21_WriteDATA(0x22);

		EPD_W21_WriteCMD(0x61);        	//tres			ɫ640*384
		EPD_W21_WriteDATA (0x02);		//source 600
		EPD_W21_WriteDATA (0x58);
		EPD_W21_WriteDATA (0x01);		//gate 448
		EPD_W21_WriteDATA (0xc0);
	
		EPD_W21_WriteCMD(0X82);			//VDCS SETTING
		EPD_W21_WriteDATA(0x1E);		//decide by LUT file

		EPD_W21_WriteCMD(0xe5);			//FLASH MODE		   	
		EPD_W21_WriteDATA(0x03);	
}


void WriteBuffer (unsigned  char *picture)
{
	unsigned long int i;
	unsigned char j,temp1,temp2;

		for(i=0;i<33600;i++)	                     
		{   
			temp1 = picture[i];
			for(j=0;j<8;j++)
			{
				if(temp1&0x80)
					temp2 = 0x00;
				else
					temp2 = 0x03;
				
				temp2 <<= 4;
				temp1 <<= 1;
				j++;

				if(temp1&0x80)
					temp2 |= 0x00;
				else
					temp2 |= 0x03;
				
				temp1 <<= 1;
				
				EPD_W21_WriteDATA(temp2); 
				
			}
			
		}
}


void DisplayRefresh(void)
{
	EPD_W21_WriteCMD(0x12);			//DISPLAY REFRESH 	
	HAL_Delay(20);	        //!!!The delay here is necessary, 200uS at least!!!     
	CheckStatus();
}



/***********************************************************
						end file
***********************************************************/

